@@ -6,19 +6,45 @@
  * $Id$
  */
 
+#include <vdr/menu.h>
 #include <vdr/remote.h>
 #include "femoncfg.h"
-#include "femoni18n.h"
 #include "femonreceiver.h"
 #include "femonosd.h"
 #include "femonservice.h"
 #include "femontools.h"
-#include "femon.h"
 
-#if defined(APIVERSNUM) && APIVERSNUM < 10400
-#error "VDR-1.4.0 API version or greater is required!"
+#if defined(APIVERSNUM) && APIVERSNUM < 10508
+#error "VDR-1.5.8 API version or greater is required!"
 #endif
 
+static const char VERSION[]       = "1.2.2";
+static const char DESCRIPTION[]   = trNOOP("DVB Signal Information Monitor (OSD)");
+static const char MAINMENUENTRY[] = trNOOP("Signal Information");
+
+class cPluginFemon : public cPlugin {
+public:
+  cPluginFemon(void);
+  virtual ~cPluginFemon();
+  virtual const char *Version(void) { return VERSION; }
+  virtual const char *Description(void) { return tr(DESCRIPTION); }
+  virtual const char *CommandLineHelp(void);
+  virtual bool ProcessArgs(int argc, char *argv[]);
+  virtual bool Initialize(void);
+  virtual bool Start(void);
+  virtual void Stop(void);
+  virtual void Housekeeping(void);
+  virtual void MainThreadHook(void) {}
+  virtual cString Active(void) { return NULL; }
+  virtual const char *MainMenuEntry(void) { return (femonConfig.hidemenu ? NULL : tr(MAINMENUENTRY)); }
+  virtual cOsdObject *MainMenuAction(void);
+  virtual cMenuSetupPage *SetupMenu(void);
+  virtual bool SetupParse(const char *Name, const char *Value);
+  virtual bool Service(const char *Id, void *Data);
+  virtual const char **SVDRPHelpPages(void);
+  virtual cString SVDRPCommand(const char *Command, const char *Option, int &ReplyCode);
+  };
+
 cPluginFemon::cPluginFemon()
 {
   // Initialize any member variables here.
@@ -54,7 +80,6 @@ bool cPluginFemon::Initialize(void)
 bool cPluginFemon::Start(void)
 {
   // Start any background activities the plugin shall perform.
-  RegisterI18n(Phrases);
   return true;
 }
 
@@ -72,7 +97,11 @@ cOsdObject *cPluginFemon::MainMenuAction(void)
 {
   // Perform the action when selected from the main VDR menu.
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
-  return cFemonOsd::Instance(true);
+  if (cReplayControl::NowReplaying())
+     Skins.Message(mtInfo, tr("Femon not available while replaying"));
+  else
+     return cFemonOsd::Instance(true);
+  return NULL;
 }
 
 bool cPluginFemon::SetupParse(const char *Name, const char *Value)
@@ -160,6 +189,10 @@ const char **cPluginFemon::SVDRPHelpPages(void)
 cString cPluginFemon::SVDRPCommand(const char *Command, const char *Option, int &ReplyCode)
 {
   if (strcasecmp(Command, "OPEN") == 0) {
+     if (cReplayControl::NowReplaying()) {
+        ReplyCode = 550; // Requested action not taken
+        return cString("Cannot open femon plugin while replaying");
+        }
      if (!cFemonOsd::Instance())
         cRemote::CallPlugin("femon");
      return cString("Opening femon plugin");
@@ -225,6 +258,20 @@ cString cPluginFemon::SVDRPCommand(const char *Command, const char *Option, int
   return NULL;
 }
 
+class cMenuFemonSetup : public cMenuSetupPage {
+private:
+  const char *dispmodes[eFemonModeMaxNumber];
+  const char *skins[eFemonSkinMaxNumber];
+  const char *themes[eFemonThemeMaxNumber];
+  cFemonConfig data;
+  virtual void Setup(void);
+protected:
+  virtual eOSState ProcessKey(eKeys Key);
+  virtual void Store(void);
+public:
+  cMenuFemonSetup(void);
+  };
+
 cMenuFemonSetup::cMenuFemonSetup(void)
 {
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
@@ -254,18 +301,18 @@ void cMenuFemonSetup::Setup(void)
   int current = Current();
 
   Clear();
-  Add(new cMenuEditBoolItem(  tr("Hide main menu entry"),        &data.hidemenu,       tr("no"),            tr("yes")));
+  Add(new cMenuEditBoolItem(  tr("Hide main menu entry"),        &data.hidemenu));
   Add(new cMenuEditStraItem(  tr("Default display mode"),        &data.displaymode,    eFemonModeMaxNumber, dispmodes));
-  Add(new cMenuEditStraItem(  tr("Skin"),                        &data.skin,           eFemonSkinMaxNumber, skins));
-  Add(new cMenuEditStraItem(  tr("Theme"),                       &data.theme,          eFemonThemeMaxNumber,themes));
-  Add(new cMenuEditBoolItem(  tr("Position"),                    &data.position,       tr("bottom"),        tr("top")));
-  Add(new cMenuEditIntItem(   tr("Height"),                      &data.osdheight,      400,                 500));
+  Add(new cMenuEditStraItem(  trVDR("Setup.OSD$Skin"),           &data.skin,           eFemonSkinMaxNumber, skins));
+  Add(new cMenuEditStraItem(  trVDR("Setup.OSD$Theme"),          &data.theme,          eFemonThemeMaxNumber,themes));
+  Add(new cMenuEditBoolItem(  tr("Position"),                    &data.position,       trVDR("bottom"),     trVDR("top")));
+  Add(new cMenuEditIntItem(   trVDR("Setup.OSD$Height"),         &data.osdheight,      400,                 500));
   Add(new cMenuEditIntItem(   tr("Horizontal offset"),           &data.osdoffset,      -50,                 50));
-  Add(new cMenuEditBoolItem(  tr("Show CA system"),              &data.showcasystem,   tr("no"),            tr("yes")));
+  Add(new cMenuEditBoolItem(  tr("Show CA system"),              &data.showcasystem));
   Add(new cMenuEditIntItem(   tr("Red limit [%]"),               &data.redlimit,       1,                   50));
   Add(new cMenuEditIntItem(   tr("Green limit [%]"),             &data.greenlimit,     51,                  100));
   Add(new cMenuEditIntItem(   tr("OSD update interval [0.1s]"),  &data.updateinterval, 1,                   100));
-  Add(new cMenuEditBoolItem(  tr("Analyze stream"),              &data.analyzestream,  tr("no"),            tr("yes")));
+  Add(new cMenuEditBoolItem(  tr("Analyze stream"),              &data.analyzestream));
   if (femonConfig.analyzestream)
      Add(new cMenuEditIntItem(tr("Calculation interval [0.1s]"), &data.calcinterval,   1,                   100));
   Add(new cMenuEditBoolItem(  tr("Use SVDRP service"),           &data.usesvdrp));
